use thiserror::Error;
use time::error::Parse;

#[derive(Error, Debug)]
#[error("data store error")]
pub enum DataStoreError {
    #[error("no results")]
    NoResults(rusqlite::Error),
    #[error("sqlite error")]
    SqliteError(rusqlite::Error),
    #[error("connection error")]
    ConnectionError(#[from] r2d2::Error),
    #[error("failed to parse datetime")]
    DateTimeError(#[from] Parse),
}

impl From<rusqlite::Error> for DataStoreError {
    fn from(error: rusqlite::Error) -> Self {
        match error {
            rusqlite::Error::QueryReturnedNoRows => DataStoreError::NoResults(error),
            _ => DataStoreError::SqliteError(error),
        }
    }
}
